@@ -7,10 +7,7 @@ Usage::
     import boto3
     from mypy_boto3_workmailmessageflow import WorkMailMessageFlowClient
 
-    session = boto3.Session()
-
     client: WorkMailMessageFlowClient = boto3.client("workmailmessageflow")
-    session_client: WorkMailMessageFlowClient = session.client("workmailmessageflow")
     ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
